@@ -1,7 +1,8 @@
-from typing import Any
+import time
 
 import serial
 import socket
+import os
 
 
 class Connect:
@@ -49,13 +50,19 @@ class Connect:
             if self.exe_location is None or not isinstance(self.exe_location, str):
                 raise Exception('When data_method value is exe... exe_location must have a string value.')
 
-    def init(self):
+    def init(self, open_exe=False):
         """
         Sets up the Connect class and returns the class. A required step before running any functions.
         """
 
+        if open_exe:
+            self.open(exe_location=self.exe_location)
+            time.sleep(5)
+
         if self.data_method == 'com':
-            port = "\\\\.\\" + str(self.com)
+            port = str(self.com)
+            if os.name == 'nt':
+                port = "\\\\.\\" + str(self.com)
             self.ser = serial.Serial(port, 4608000, timeout=0)
         elif self.data_method == 'socket':
             self.mainSocket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -66,7 +73,17 @@ class Connect:
 
         return self
 
-    def read_line(self, do_check=True) -> str | Exception | None:
+    def open(self, exe_location, params=None):
+        if self.data_method == 'com':
+            raise Exception("This function open is not available for this data_method")
+        elif self.data_method == 'socket':
+            os.system(exe_location)
+        elif self.data_method == 'exe':
+            return Exception("The data_method exe has not been implemented yet")
+
+        return self
+
+    def read_line(self, do_check=True):
         """
         Returns string of the latest data from the CTS. Returns None if no data is there.
 
@@ -85,7 +102,7 @@ class Connect:
         elif self.data_method == 'exe':
             return Exception("The data_method exe has not been implemented yet")
 
-    def get_cords(self, do_check=True) -> [float]:
+    def get_cords(self, do_check=True):
         """
         Returns array of the latest data from the CTS. Returns empty array if no data is there.
 
